| dmb | R Documentation |
Density, distribution function, quantile function, and random generation for the
MBBEFD distribution with parameters g and b.
dmb(x, g, b, c = NULL, log = FALSE)
pmb(q, g, b, c = NULL, lower.tail = TRUE, log.p = FALSE)
qmb(p, g, b, c = NULL, lower.tail = TRUE, log.p = FALSE)
rmb(n, g, b, c = NULL)
x, q |
numeric; vector of quantiles. |
p |
numeric; vector of probabilities. |
n |
numeric; number of observations. If |
g |
numeric; (vector of) the |
b |
numeric; (vector of) the |
c |
numeric; (vector of) the optional single |
log, log.p |
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
The MBBEFD class of curves are defined in Bernegger (1997) and are
often used to model insurance risk. The density is defined on the semi-open
interval [0, 1) and the distribution and quantile functions are defined on
the closed interval [0, 1]. The parameters must satisfy g \ge 1 and
b \ge 0.
dmb gives the density, pmb gives the distribution function,
qmb gives the quantile function, and rmb generates random
deviates.
The length of the result is determined by n for rmb, and is the
length of x, p, or q as appropriate for the other
functions.
Numerical arguments other than n are recycled to the length of the
result. Logical arguments should be of length 1.
This package follows Bernegger's convention that the density function does not exist at 1. This differs from the mbbefd package.
Avraham Adler Avraham.Adler@gmail.com
Bernegger, S. (1997) The Swiss Re Exposure Curves and the MBBEFD Distribution Class. ASTIN Bulletin 27(1), 99–111. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2143/AST.27.1.563208")}
mommb for parameter estimation.
all.equal(dmb(0.5, 1, 0), 0)
dmb(0.2, 20, 5)
pmb(0.98, 25, 4)
qmb(0.98, 25, 4) == 1
all.equal(qmb(pmb(0.98, 25, 4), 25, 4), 0.98)
set.seed(45)
rmb(3, 4, 12)
set.seed(45)
rmb(99:101, 4, 12) # length(99:101) = 3, so generates same 3 values as above
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.